@@ -7,24 +7,29 @@ def error_handler(resource):
     return {response.json()['error']}
 
 def getResource():
-    url = "http://job-management.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/resources"
+    url = "http://quantum-resource.qcc.svc.cluster.local:8080"
+    url_path = f"{url}/v1/resources"
 
-    response = requests.get(f"{url_path}") # , params=params)
+    params = {
+        "page": -1,
+        "size": 0
+    }
+
+    response = requests.get(f"{url_path}", params=params)
     
     if response.status_code != 200:
         return error_handler(response)
 
     data = json.loads(response.content)
-    print("{:<5} {:<15} {:<5} {:<10} {:<10} {:<15}".format("id", "name", "type", "status", "qubits", "gates"))
+    print("{:<40} {:<15} {:<10} {:<10} {:<10}".format("id", "name", "type", "status", "qubits"))
     for vals in data["resources"]:
-        print("{:<5} {:<15} {:<5} {:<10} {:<10} {:<15}".format(vals["id"], vals["name"], vals["type"], vals["status"], vals["qubits"], str(vals["gates"])))
+        print("{:<40} {:<15} {:<10} {:<10} {:<10}".format(vals["id"], vals["name"], vals["type"], vals["status"], vals["qubits"]))
 
     return response.text
 
 def getResourceName(resourceId):
-    url = "http://job-management.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/resources"
+    url = "http://job-management.qcc.svc.cluster.local:8080"
+    url_path = f"{url}/v1/resources/{resourceID}"
 
     response = requests.get(f"{url_path}") # , params=params)
     
@@ -32,7 +37,4 @@ def getResourceName(resourceId):
         return error_handler(response)
 
     data = json.loads(response.content)
-    for vals in data["resources"]:
-        if vals["id"] == resourceId:
-            return vals["name"]
-    return "[ERROR] Not found."
\ No newline at end of file
+    return data["name"]
\ No newline at end of file
